@@ -23,7 +23,7 @@ class Slide(Orderable):
     file = FileField(_('File'), max_length=200, upload_to='slides', format='Image')
     description = models.CharField(_('Description'), blank=True, max_length=200)
     caption = models.CharField(_('Caption'), blank=True, max_length=200)
-    site = models.ForeignKey(Site, default=0)
+    site = models.ForeignKey(Site)
 
     class Meta:
         verbose_name = _('Slide')
